@@ -224,17 +224,6 @@ class ToolbarTitle(Gtk.Bin):
         self.__signal_id = self.__entry.connect("changed",
                                                 self.__on_entry_changed)
 
-    def add_dot_com(self):
-        """
-            Add dot com to URI
-        """
-        bounds = self.__entry.get_selection_bounds()
-        if bounds:
-            current = self.__entry.get_text()[:bounds[0]]
-        else:
-            current = self.__entry.get_text()
-        self.set_text_entry(current + ".com")
-
     def set_uri(self, uri):
         """
             Update internal uri
@@ -337,15 +326,15 @@ class ToolbarTitle(Gtk.Bin):
 
     def show_input_warning(self, webview):
         """
-            Show a message to user about password input field over http
+            Show a message to user about password input field over HTTP
             @param webview as WebView
         """
         if self.__input_warning_shown:
             return
         self.__input_warning_shown = True
         self.show_message(_(
-            "Heads-up: this page is not secure.\n"
-            "If you type your password,\n it will be "
+            "Heads-up: This page is insecure.\n"
+            "If you type your password,\nit will be "
             "visible to cybercriminals!"))
 
     def show_readable_button(self, b):
@@ -393,7 +382,7 @@ class ToolbarTitle(Gtk.Bin):
         """
         if indicator == Indicator.GEOLOCATION:
             self.__indicator2.show()
-            self.__indicator2.set_tooltip_text(_("Disallow geolocation"))
+            self.__indicator2.set_tooltip_text(_("Deny geolocation"))
             self.__indicator2_image.set_from_icon_name(
                 "mark-location-symbolic",
                 Gtk.IconSize.MENU)
@@ -565,6 +554,13 @@ class ToolbarTitle(Gtk.Bin):
                 value = webview.get_prev_text_entry(uri)
             elif event.keyval == Gdk.KEY_Z:
                 value = webview.get_next_text_entry()
+            elif event.keyval == Gdk.KEY_Return:
+                bounds = self.__entry.get_selection_bounds()
+                if bounds:
+                    current = self.__entry.get_text()[:bounds[0]]
+                else:
+                    current = self.__entry.get_text()
+                value = current + ".com"
             if value is not None:
                 self.set_text_entry(value)
                 self.__entry.emit("changed")
@@ -794,10 +790,14 @@ class ToolbarTitle(Gtk.Bin):
             @param encoding as str
             @param value as str
         """
-        if status and value == self.__entry.get_text():
+        current_text = self.__entry.get_text()
+        if status and value == current_text:
             string = content.decode(encoding)
             # format: '["{"words"}",["result1","result2"]]'
-            sgs = string.replace('[', '').replace(']', '').split(',')[1:]
+            sgs = string.replace('[', '')\
+                        .replace(']', '')\
+                        .replace('"', '')\
+                        .split(',')[1:]
             self.__popover.add_suggestions(sgs)
 
     def __populate_completion(self, uri):
@@ -817,6 +817,7 @@ class ToolbarTitle(Gtk.Bin):
         def model_append(array):
             if self.__completion_model_clear_timeout_id is not None:
                 GLib.source_remove(self.__completion_model_clear_timeout_id)
+                self.__completion_model_clear_timeout_id = None
             if self.__completion_model_append_timeout_id is not None:
                 GLib.source_remove(self.__completion_model_append_timeout_id)
             self.__completion_model_append_timeout_id = \
@@ -948,9 +949,9 @@ class ToolbarTitle(Gtk.Bin):
 
         self.__cancellable.cancel()
         self.__cancellable.reset()
-        parsed = urlparse(value)
 
         network = Gio.NetworkMonitor.get_default().get_network_available()
+        parsed = urlparse(value)
         is_uri = parsed.scheme in ["about, http", "file", "https", "populars"]
         if is_uri:
             self.__popover.set_search_text(parsed.netloc + parsed.path)
